==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_languages/html_web_languages/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Language Bindings", "index.html", [
    [ "The StarPU Native Fortran Support", "NativeFortranSupport.html", [
      [ "Implementation Details and Specificities", "NativeFortranSupport.html#NFImplementation", [
        [ "Prerequisites", "NativeFortranSupport.html#NFPrerequisites", null ],
        [ "Configuration", "NativeFortranSupport.html#NFConfiguration", null ],
        [ "Examples", "NativeFortranSupport.html#NFExamples", null ],
        [ "Compiling a Native Fortran Application", "NativeFortranSupport.html#NFAppCompile", null ]
      ] ],
      [ "Fortran Translation for Common StarPU API Idioms", "NativeFortranSupport.html#NFIdioms", null ],
      [ "Uses, Initialization and Shutdown", "NativeFortranSupport.html#NFInitExit", null ],
      [ "Fortran Flavor of StarPU's Variadic Insert_task", "NativeFortranSupport.html#NFInsertTask", null ],
      [ "Functions and Subroutines Expecting Data Structures Arguments", "NativeFortranSupport.html#NFStructs", null ],
      [ "Additional Notes about the Native Fortran Support", "NativeFortranSupport.html#NFNotes", [
        [ "Using StarPU with Older Fortran Compilers", "NativeFortranSupport.html#NFOldFortran", null ],
        [ "Valid API Mixes and Language Mixes", "NativeFortranSupport.html#NFAPIMIX", null ]
      ] ]
    ] ],
    [ "StarPU Java Interface", "StarPUJavaInterface.html", null ],
    [ "Python Interface", "PythonInterface.html", [
      [ "Installation of the Python Interface", "PythonInterface.html#Installation", null ],
      [ "Python Parallelism", "PythonInterface.html#PythonParallelism", null ],
      [ "Using StarPU in Python", "PythonInterface.html#ImplementingStarPUInPython", [
        [ "Submitting Tasks", "PythonInterface.html#SubmittingTasks", null ],
        [ "Returning Future Object", "PythonInterface.html#ReturningFutureObject", null ],
        [ "Submit Python Objects Supporting The Buffer Protocol", "PythonInterface.html#SubmitPythonBuffer", [
          [ "Access Mode Annotation", "PythonInterface.html#AnnotationAccess", null ],
          [ "Methods", "PythonInterface.html#MethodsAcquireRelease", null ]
        ] ]
      ] ],
      [ "StarPU Data Interface for Python Objects", "PythonInterface.html#StarPUPYInterface", [
        [ "Interface for Ordinary Python Objects", "PythonInterface.html#PythonObject", null ],
        [ "Interface for Python Objects Supporting Buffer Protocol", "PythonInterface.html#PythonBuffer", [
          [ "Methods", "PythonInterface.html#Methods", null ]
        ] ],
        [ "Interface for Empty Numpy Array", "PythonInterface.html#EmptyNumpy", null ],
        [ "Array Partitioning", "PythonInterface.html#HandlePartition", null ]
      ] ],
      [ "Benchmark", "PythonInterface.html#Benchmark", null ],
      [ "Running Python Functions as Pipeline Jobs (Imitating Joblib Library)", "PythonInterface.html#ImitatingJoblibLibrary", [
        [ "Examples", "PythonInterface.html#JobLibraryExamples", null ],
        [ "Parallel Parameters", "PythonInterface.html#ParallelParameters", null ],
        [ "Performances", "PythonInterface.html#JobLibPerformances", null ]
      ] ],
      [ "Multiple Interpreters", "PythonInterface.html#MultipleInterpreters", null ],
      [ "Master Slave Support", "PythonInterface.html#StarpupyMasterSlave", null ]
    ] ],
    [ "The StarPU OpenMP Runtime Support (SORS)", "OpenMPRuntimeSupport.html", [
      [ "Implementation Details and Specificities", "OpenMPRuntimeSupport.html#OMPImplementation", [
        [ "Main Thread", "OpenMPRuntimeSupport.html#OMPMainThread", null ],
        [ "Extended Task Semantics", "OpenMPRuntimeSupport.html#OMPTaskSemantics", null ]
      ] ],
      [ "Configuration", "OpenMPRuntimeSupport.html#OMPConfiguration", null ],
      [ "Initialization and Shutdown", "OpenMPRuntimeSupport.html#OMPInitExit", null ],
      [ "Parallel Regions and Worksharing", "OpenMPRuntimeSupport.html#OMPSharing", [
        [ "Parallel Regions", "OpenMPRuntimeSupport.html#OMPParallel", null ],
        [ "Parallel For", "OpenMPRuntimeSupport.html#OMPFor", null ],
        [ "Sections", "OpenMPRuntimeSupport.html#OMPSections", null ],
        [ "Single", "OpenMPRuntimeSupport.html#OMPSingle", null ]
      ] ],
      [ "Tasks", "OpenMPRuntimeSupport.html#OMPTask", [
        [ "Explicit Tasks", "OpenMPRuntimeSupport.html#OMPTaskExplicit", null ],
        [ "Data Dependencies", "OpenMPRuntimeSupport.html#OMPDataDependencies", null ],
        [ "TaskWait and TaskGroup", "OpenMPRuntimeSupport.html#OMPTaskSyncs", null ]
      ] ],
      [ "Synchronization Support", "OpenMPRuntimeSupport.html#OMPSynchronization", [
        [ "Simple Locks", "OpenMPRuntimeSupport.html#OMPSimpleLock", null ],
        [ "Nestable Locks", "OpenMPRuntimeSupport.html#OMPNestableLock", null ],
        [ "Critical Sections", "OpenMPRuntimeSupport.html#OMPCritical", null ],
        [ "Barriers", "OpenMPRuntimeSupport.html#OMPBarrier", null ]
      ] ],
      [ "Example: An OpenMP LLVM Support", "OpenMPRuntimeSupport.html#OMPLLVM", null ],
      [ "OpenMP Standard Functions in StarPU", "OpenMPRuntimeSupport.html#OMPStandard", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#a9adac8be1a174cb4ad9d8e68c2ec7678",
"group__API__Data__Interfaces.html#ac01fd0c59e0a5740ab8b000a2681f0aa",
"group__API__Data__Interfaces.html#gafd9d133c4d658b777d9800eba79765b3",
"group__API__FxT__Support.html#ae8825a6b5c62dd05bdc8508c9f0bf09c",
"group__API__MPI__FT__Support.html#ga32a3aa7dc7e387ac0fd7eb89ca11b912",
"group__API__Modularized__Scheduler.html#gae1aa931285a2b952473fc7def121c5cd",
"group__API__Parallel__Worker.html#gadc0266b4a673ad33bb6a39eaf22afc08",
"group__API__Profiling.html#gacf0b5499290848f07c97a32c6c2412db",
"group__API__Scheduling__Policy.html#ga3bf8df94c9ea3f1370b53fff54e72888",
"group__API__Workers.html#ga6312aa4b12ce7e06fe391bcafda6796a",
"interfacefstarpu__mod_1_1fstarpu__data__partition__readonly__submit.html",
"interfacefstarpu__mod_1_1fstarpu__sched__set__min__priority.html",
"sc__hypervisor__config_8h.html#a002798d04e272d4901e06d2909e2d970"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.5-2.src.tar.zst: starpu-1.4.5/doc/doxygen_web_languages/html_web_languages/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Language Bindings", "index.html", [
    [ "The StarPU Native Fortran Support", "NativeFortranSupport.html", [
      [ "Implementation Details and Specificities", "NativeFortranSupport.html#NFImplementation", [
        [ "Prerequisites", "NativeFortranSupport.html#NFPrerequisites", null ],
        [ "Configuration", "NativeFortranSupport.html#NFConfiguration", null ],
        [ "Examples", "NativeFortranSupport.html#NFExamples", null ],
        [ "Compiling a Native Fortran Application", "NativeFortranSupport.html#NFAppCompile", null ]
      ] ],
      [ "Fortran Translation for Common StarPU API Idioms", "NativeFortranSupport.html#NFIdioms", null ],
      [ "Uses, Initialization and Shutdown", "NativeFortranSupport.html#NFInitExit", null ],
      [ "Fortran Flavor of StarPU's Variadic Insert_task", "NativeFortranSupport.html#NFInsertTask", null ],
      [ "Functions and Subroutines Expecting Data Structures Arguments", "NativeFortranSupport.html#NFStructs", null ],
      [ "Additional Notes about the Native Fortran Support", "NativeFortranSupport.html#NFNotes", [
        [ "Using StarPU with Older Fortran Compilers", "NativeFortranSupport.html#NFOldFortran", null ],
        [ "Valid API Mixes and Language Mixes", "NativeFortranSupport.html#NFAPIMIX", null ]
      ] ]
    ] ],
    [ "StarPU Java Interface", "StarPUJavaInterface.html", null ],
    [ "Python Interface", "PythonInterface.html", [
      [ "Installation of the Python Interface", "PythonInterface.html#Installation", null ],
      [ "Python Parallelism", "PythonInterface.html#PythonParallelism", null ],
      [ "Using StarPU in Python", "PythonInterface.html#ImplementingStarPUInPython", [
        [ "Submitting Tasks", "PythonInterface.html#SubmittingTasks", null ],
        [ "Returning Future Object", "PythonInterface.html#ReturningFutureObject", null ],
        [ "Submit Python Objects Supporting The Buffer Protocol", "PythonInterface.html#SubmitPythonBuffer", [
          [ "Access Mode Annotation", "PythonInterface.html#AnnotationAccess", null ],
          [ "Methods", "PythonInterface.html#MethodsAcquireRelease", null ]
        ] ]
      ] ],
      [ "StarPU Data Interface for Python Objects", "PythonInterface.html#StarPUPYInterface", [
        [ "Interface for Ordinary Python Objects", "PythonInterface.html#PythonObject", null ],
        [ "Interface for Python Objects Supporting Buffer Protocol", "PythonInterface.html#PythonBuffer", [
          [ "Methods", "PythonInterface.html#Methods", null ]
        ] ],
        [ "Interface for Empty Numpy Array", "PythonInterface.html#EmptyNumpy", null ],
        [ "Array Partitioning", "PythonInterface.html#HandlePartition", null ]
      ] ],
      [ "Benchmark", "PythonInterface.html#Benchmark", null ],
      [ "Running Python Functions as Pipeline Jobs (Imitating Joblib Library)", "PythonInterface.html#ImitatingJoblibLibrary", [
        [ "Examples", "PythonInterface.html#JobLibraryExamples", null ],
        [ "Parallel Parameters", "PythonInterface.html#ParallelParameters", null ],
        [ "Performances", "PythonInterface.html#JobLibPerformances", null ]
      ] ],
      [ "Multiple Interpreters", "PythonInterface.html#MultipleInterpreters", null ],
      [ "Master Slave Support", "PythonInterface.html#StarpupyMasterSlave", null ],
      [ "StarPUPY and Simgrid", "PythonInterface.html#StarPUPYSimgrid", null ]
    ] ],
    [ "The StarPU OpenMP Runtime Support (SORS)", "OpenMPRuntimeSupport.html", [
      [ "Implementation Details and Specificities", "OpenMPRuntimeSupport.html#OMPImplementation", [
        [ "Main Thread", "OpenMPRuntimeSupport.html#OMPMainThread", null ],
        [ "Extended Task Semantics", "OpenMPRuntimeSupport.html#OMPTaskSemantics", null ]
      ] ],
      [ "Configuration", "OpenMPRuntimeSupport.html#OMPConfiguration", null ],
      [ "Initialization and Shutdown", "OpenMPRuntimeSupport.html#OMPInitExit", null ],
      [ "Parallel Regions and Worksharing", "OpenMPRuntimeSupport.html#OMPSharing", [
        [ "Parallel Regions", "OpenMPRuntimeSupport.html#OMPParallel", null ],
        [ "Parallel For", "OpenMPRuntimeSupport.html#OMPFor", null ],
        [ "Sections", "OpenMPRuntimeSupport.html#OMPSections", null ],
        [ "Single", "OpenMPRuntimeSupport.html#OMPSingle", null ]
      ] ],
      [ "Tasks", "OpenMPRuntimeSupport.html#OMPTask", [
        [ "Explicit Tasks", "OpenMPRuntimeSupport.html#OMPTaskExplicit", null ],
        [ "Data Dependencies", "OpenMPRuntimeSupport.html#OMPDataDependencies", null ],
        [ "TaskWait and TaskGroup", "OpenMPRuntimeSupport.html#OMPTaskSyncs", null ]
      ] ],
      [ "Synchronization Support", "OpenMPRuntimeSupport.html#OMPSynchronization", [
        [ "Simple Locks", "OpenMPRuntimeSupport.html#OMPSimpleLock", null ],
        [ "Nestable Locks", "OpenMPRuntimeSupport.html#OMPNestableLock", null ],
        [ "Critical Sections", "OpenMPRuntimeSupport.html#OMPCritical", null ],
        [ "Barriers", "OpenMPRuntimeSupport.html#OMPBarrier", null ]
      ] ],
      [ "Example: An OpenMP LLVM Support", "OpenMPRuntimeSupport.html#OMPLLVM", null ],
      [ "OpenMP Standard Functions in StarPU", "OpenMPRuntimeSupport.html#OMPStandard", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#a96fce0a6c6188a069d4bf2cc59e5400c",
"group__API__Data__Interfaces.html#abf4cecec3e8bcec447ec51416b8ac3d2",
"group__API__Data__Interfaces.html#gafd439524218c70b6b4a784fb12824c28",
"group__API__FxT__Support.html#a66ac04619aec557f95ddf5a5df848341",
"group__API__Interop__Support.html#gga33d15f419efaa08bf329d25f054fa632a40bf5a989027582689067f00115c1653",
"group__API__Modularized__Scheduler.html#gaccfaa23c5e0948fec6be5f71fc69f32c",
"group__API__Parallel__Worker.html#gab630219c3f24cfa1b3c096bdd19d5868",
"group__API__Profiling.html#ga9373d4a06c86ebf9ae74b67233b8bad6",
"group__API__Scheduling__Policy.html#ga3893905aa0eb62a541f268c6f37c491e",
"group__API__Workers.html#ga5728fe0e4be069e45c4cd0ac0319d8a0",
"interfacefstarpu__mod_1_1fstarpu__data__map__filters.html",
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__worker__is__master__for__child__ctx.html",
"interfacestarpu__mod_1_1starpu__task__wait__for__all.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
